@@ -3,17 +3,18 @@ from contextlib import contextmanager
 from datetime import date as real_date, datetime as real_datetime, timedelta
 import re
 import sys
+import time
 
 from mock import patch as mockpatch
 
-__version__ = '0.1.1'
+__version__ = '0.1.4'
 
 _patch_contexts = []
 
 contextinfo = namedtuple('contextinfo', 'relnow modules patches')
 
 #: Never patch these modules (unless explicitly demanded)
-always_exclude = set([__name__, 'datetime', 'six.moves.'])
+always_exclude = {__name__, 'datetime', 'six.moves.', 'dateutil', 'pkg_resources'}
 
 
 class FrozenDateMeta(type):
@@ -44,15 +45,23 @@ class RelativeNow(object):
     - A datetime value starting at ``when``, updating in realtime (hard=False)
     """
     def __init__(self, when, hard):
-        self.basetime = when
+        self.basetime = time.mktime(when.timetuple())
         self.hard = hard
-        self.created_at = real_datetime.now()
+        self.created_at = time.time()
 
-    def __call__(self):
+    def now(self, tz=None):
         if self.hard:
-            return self.basetime
-        offset = real_datetime.now() - self.created_at
-        return self.basetime + offset
+            offset = 0
+        else:
+            offset = time.time() - self.created_at
+        return real_datetime.fromtimestamp(self.basetime + offset, tz)
+
+    def utcnow(self):
+        if self.hard:
+            offset = 0
+        else:
+            offset = time.time() - self.created_at
+        return real_datetime.utcfromtimestamp(self.basetime + offset)
 
 
 class FrozenDate(real_date):
@@ -61,7 +70,7 @@ class FrozenDate(real_date):
 
     @classmethod
     def today(cls):
-        return cls.relnow().date()
+        return cls.relnow.now().date()
 
 
 class FrozenDatetime(real_datetime):
@@ -70,11 +79,15 @@ class FrozenDatetime(real_datetime):
 
     @classmethod
     def today(cls):
-        return cls.relnow()
+        return cls.relnow.now()
 
     @classmethod
-    def now(cls):
-        return cls.relnow()
+    def now(cls, tz=None):
+        return cls.relnow.now(tz)
+
+    @classmethod
+    def utcnow(cls):
+        return cls.relnow.utcnow()
 
 
 def _get_to_patch(kwargs):
@@ -274,7 +287,7 @@ def now():
     """
     try:
         ci = current_patch_context()
-        return ci.relnow()
+        return ci.relnow.now()
     except IndexError:
         return real_datetime.now()
 
